Contributing to the Longaccess client
=====================================

The project encourages contributions to this project from anyone. Such
contributions increase the value of the provided software to the public, under
the terms of the relevant license (see the included LICENSE document).
Contributing bug fixes and implementing new features in the TODO file are
especially encouraged. If certain requirements are met (see below) we will be
glad to incorporate your contributions into the software.

Apart from hacking on the client you may also help by reporting issues that you
or others are having while using the software, answering questions about issues
that other users might have as well as contributing documentation.

Source code
-----------

When applicable contributions should be made against the latest version of the
source code. The latest source code for the software can be obtained through
the web, or via the GIT version control program. See the following address for
these options:

http://github.com/longaccess/longaccess-client


Coding Standards
----------------

Contributed code should follow the [coding standards, outlined here][cs], for example we
use four spaces for indentation and generally follow [PEP8][].

[PEP8]: http://www.python.org/dev/peps/pep-0008/ "PEP8: Style Guide for Python Code"
[cs]: CODING-STYLE.md "CODING-STYLE.md : coding standards for Longaccess"

Copyright Assignment
--------------------

LONG ACCESS Private Company is the copyright holder for Longaccess. For more
information about the company see:l

http://www.longaccess.com

Small contributions can be accepted without any special copyright assignment on
the part of the contributor but, generally speaking, contributors are required
to assign copyright to LONG ACCESS Private Company. Please get in touch with us for
more details.
